@@ -86,7 +86,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x54c00
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x54f00
 #  endif
 #endif
 
